@@ -1,4 +1,3 @@
-/* $XFree86: xc/programs/Xserver/hw/xfree86/dummylib/verrorfverb.c,v 1.2 2003/08/25 04:13:05 dawes Exp $ */
 
 #ifdef HAVE_XORG_CONFIG_H
 #include <xorg-config.h>
@@ -13,7 +12,7 @@
  * Utility functions required by libxf86_os. 
  */
 
-void
+_X_EXPORT void
 LogVWrite(int verb, const char *format, va_list ap)
 {
     if (xf86Verbose >= verb)
